@@ -2,9 +2,6 @@ import base64
 import os
 import sqlite3
 from pathlib import Path as Pathlib_path
-import click
-from flask import current_app, g
-from flask.cli import with_appcontext
 
 static_images = os.path.dirname(os.path.abspath(__file__)) + "/static/images/styles/small/"
 save_parent_folder = "/storage/emulated/0/Music/EisenRadio"
@@ -27,45 +24,6 @@ def render_picture(byte_data, de_enc):
     return render_pic
 
 
-def get_db():
-    if 'db' not in g:
-        g.db = sqlite3.connect(
-            current_app.config['DATABASE'],
-            detect_types=sqlite3.PARSE_DECLTYPES
-        )
-        g.db.row_factory = sqlite3.Row
-
-    return g.db
-
-
-def close_db(e=None):
-    db = g.pop('db', None)
-
-    if db is not None:
-        db.close()
-
-
-def init_db():
-    db = get_db()
-
-    with current_app.open_resource((os.path.join(script_path, 'schema.sql'))) as file_schema:
-        db.executescript(file_schema.read().decode('utf8'))
-    make_db_from_schema()
-
-
-@click.command('init-db')
-@with_appcontext
-def init_db_command():
-    """Clear the existing data and create new tables."""
-    init_db()
-    click.echo('Initialized the database.')
-
-
-def init_app(app):
-    app.teardown_appcontext(close_db)
-    app.cli.add_command(init_db_command)
-
-
 def make_db_from_schema():
     # # # # custom filled db # # #
     connection = ''
@@ -173,23 +131,33 @@ def make_db_from_schema():
     cur.execute(
         "INSERT INTO posts (title, content, download_path, pic_comment, pic_content_type, pic_data) VALUES (?, ?, ?, "
         "?, ?, ?)",
-        ('Boradio',
-         'http://www.boradio.nl:8000/aacp',
+        ('zen',
+         'https://radio4.cdm-radio.com:18004/stream-mp3-Zen',
          save_parent_folder,
-         'aacp file format, vlc can read it',
+         '',
          "image/png",
-         convert_ascii(static_images + "radio3d-style-white-neongreen_120x200.png"))
+         convert_ascii(static_images + "radio3d-style-white-white_120x200.png"))
         )
     cur.execute(
         "INSERT INTO posts (title, content, download_path, pic_comment, pic_content_type, pic_data) VALUES (?, ?, ?, "
         "?, ?, ?)",
         ('B2',
-         'https://radiob2-national.cast.addradio.de/radiob2/national/mp3/high/stream.mp3?ar-distributor=ffa0',
+         'https://radiob2-national.cast.addradio.de/radiob2/national/mp3/high/stream.mp3',
          save_parent_folder,
          'german (deutsch) only',
          "image/png",
          convert_ascii(static_images + "radio3d-style-white-violet_120x200.png"))
         )
+    cur.execute(
+        "INSERT INTO posts (title, content, download_path, pic_comment, pic_content_type, pic_data) VALUES (?, ?, ?, "
+        "?, ?, ?)",
+        ('Reggae',
+         'http://hd.lagrosseradio.info:8000/lagrosseradio-reggae-192.mp3',
+         save_parent_folder,
+         '',
+         "image/png",
+         convert_ascii(static_images + "radio3d-style-white-neongreen_120x200.png"))
+        )
     connection.commit()
     connection.close()
 
