@@ -108,7 +108,7 @@ function animateParticle(ctx, animation) {
                 const dx = particlesArray[i].x - particlesArray[j].x;
                 const dy = particlesArray[i].y - particlesArray[j].y;
                 const distance = Math.sqrt(dx * dx + dy * dy);   // coord. particle x and particle y; hypotenuse; a²+b²=c²
-                if (distance < 100) {
+                if (distance < 150) {
                     ctx.beginPath();
                     ctx.strokeStyle = particlesArray[i].color;
                     ctx.lineWidth = particlesArray[i].size/10;
@@ -301,12 +301,13 @@ function pageCoverAnimation() {
 
     requestAnimationFrame(pageCoverAnimation);
     animateParticle(pageCoverCanvasCtx, 'lineAnimation');
-    if ((counter % 60) == 0) {
+    if ((counter % 90) == 0) {
         if (particlesColorSwitch) {
-            initParticles(pageCoverCanvas, pageCoverCanvasCtx, 'SandyBrown', 'gold', 20, 20, 1);
+            // initParticles (canvas, context, fill, stroke, numParticles, maxSize, minSize)
+            initParticles(pageCoverCanvas, pageCoverCanvasCtx, 'SandyBrown', 'gold', 12, 16, 12);
             particlesColorSwitch = false;
         } else {
-            initParticles(pageCoverCanvas, pageCoverCanvasCtx, 'coral', 'gold', 10, 20, 1);
+            initParticles(pageCoverCanvas, pageCoverCanvasCtx, 'coral', 'gold', 12, 16, 12);
             particlesColorSwitch = true;
         }
         counter = 0;
@@ -626,18 +627,6 @@ function initStarFieldEnv(){
 }
 ;
 
-function popper_org() {
-    canvasMasterCtx.clearRect(0,0,canvasMaster.width,canvasMaster.height);
-    $.each(floatingStageParticles, function (idx, val) {
-        let particle = val;
-        particle.update();
-        particle.draw();
-    });
-
-    requestIdAnimationFrame = window.requestAnimationFrame(popper);
-}
-;
-
 function visualiseAudio(var_canvas) {
     stopVisualise();
     currentRadio = document.getElementById('currentRadioName').innerText;
@@ -688,8 +677,6 @@ function visualiseAudio(var_canvas) {
 
         if (analyserRandom == 6) {
                                     // initFloatingStage();
-                                    // popper();
-                                    initPopper();
                                     }
 
     } catch (error) { console.error(error); }
