@@ -5,7 +5,6 @@ const canvasMaster = document.getElementById("canvasMaster");
 const canvasMasterCtx = canvasMaster.getContext('2d');
 const currentRadioName = document.getElementById('currentRadioName');
 const fileUpload = document.getElementById("fileUpload");
-const localHostSoundRoute = "http://localhost:5050/sound/"
 const playBtn = document.getElementById("playBtn");
 const pauseBtn = document.getElementById("pauseBtn");
 const audio = document.getElementById("audioWithControls");
@@ -16,6 +15,47 @@ var audioContext, audioSource, analyserNode, gainNode, analyserRandom;
 var spectrumAnalyserActive = false;
 var spectrumAnalyserShow = false;
 
+$(document).ready(function () {
+
+    pageCoverAnimation();
+    darkModeGet();
+    stationGet();
+    streamerGet();
+
+    setInterval(deleteInfo, 15005);
+    setInterval(headerInfo, 10004);
+    setInterval(toggleShowSelectBox, 5003);
+    setInterval(updateMasterProgress, 5002);
+    setInterval(updateDisplay, 5001);
+
+    $('[data-toggle="tooltip"]').tooltip()
+    $("button").click(recOrListenAction)
+    pageCover.addEventListener('click', removePageCover);
+    audioVolumeController.addEventListener("input", setAudioVolume);
+    audioGainController.addEventListener("input", setAudioGain);
+    fileUpload.addEventListener("change", playLocalAudio);
+    
+    audio.addEventListener("play", function () {
+        playBtn.style.display = "none";
+        pauseBtn.style.display = "block";
+        pauseBtn.style.cursor = "pointer";
+        pauseBtn.style.cursor = "hand";
+        $("#pauseBtn").on('click', function () {
+            audio.pause();
+        });
+    });
+    audio.addEventListener("pause", function () {
+        playBtn.style.display = "block";
+        pauseBtn.style.display = "none";
+        playBtn.style.cursor = "pointer";
+        playBtn.style.cursor = "hand";
+        $("#playBtn").on('click', function () {
+            audio.play();
+        });
+    });
+
+})
+;
 
 function setAudioContextVisual() {
     audioContext = new AudioContext();
@@ -41,10 +81,14 @@ function removePageCover() {
     pageCover.style.display = "none";
     pageCoverCanvas.style.display = "none";
     setAudioContextVisual();
+    cookie_start_set_text_show_visuals();
 }
 ;
 
 function setAudioVolume() {
+        /*
+    audioVolumeController has hardcoded safety init value of 25 (0.25 audio)
+    */
     audio.volume = audioVolumeController.value / 100;
 }
 ;
@@ -101,7 +145,7 @@ function updateDisplay() {
     });
 
     req.done(function (data) {
-        let displays_dict = data.result
+        let displays_dict = data.updateDisplay
         $.each(displays_dict, function (idx, val) {
             let radioId = idx;
             let textInfo = val;
@@ -113,7 +157,7 @@ function updateDisplay() {
 }
 ;
 
-function updateMasterprogress() {
+function updateMasterProgress() {
     var req;
 
     req = $.ajax({
@@ -138,41 +182,39 @@ function updateMasterprogress() {
         }
 
     });
-
-
 }
 ;
 
-function setDarkmode() {
+function setDarkMode() {
     let req;
 
     req = $.ajax({
         type: 'POST',
-        url: "/setcookiedark",
+        url: "/cookie_set_dark",
         cache: false
     });
 
 }
 ;
 
-function delDarkmode() {
+function delDarkMode() {
     let req;
 
     req = $.ajax({
         type: 'POST',
-        url: "/delcookiedark",
+        url: "/cookie_del_dark",
         cache: false
     });
 
 }
 ;
 
-function getDarkmode() {
+function darkModeGet() {
     let req;
 
     req = $.ajax({
         type: 'GET',
-        url: "/getcookiedark",
+        url: "/cookie_get_dark",
         cache: false
     });
 
@@ -190,127 +232,62 @@ function getDarkmode() {
 }
 ;
 
-function cookie_set_station(station, station_id) {
+function stationGet() {
+        /*
+    the active radio name listened;
+    rebuild console after page refresh
+    */
     let req;
-
-    req = $.ajax({
-        type: 'POST',
-        url: "/cookie_set_station",
-        cache: false,
-        dataType: "json",
-        data: { 'station': station, 'station_id': station_id }
-    });
-}
-;
-
-function cookie_get_station() {
-    let req;
-
     req = $.ajax({
         type: 'GET',
-        url: "/cookie_get_station",
-        cache: false
+        url: "/station_get",
+        cache: false,
     });
-
     req.done(function (data) {
-        let play_station = '';
-        if (data.play_station !== null) {
-            if (data.play_station !== ',') {
-                play_station = data.play_station.split(",");
-                let station = play_station[0];
-                let station_id = play_station[1];
+        if (data.stationGet) {
+            let stationDict = data.stationGet
+            let keyList = Object.keys(stationDict);
 
-                document.getElementById('currentRadioName').innerText = station; /*station.substring(0, 20)*/
-                document.getElementById('currentRadioName').setAttribute("id", "currentRadioName");
-
-                document.getElementById('currentRadioName').style.cursor = "pointer";
-                document.getElementById('currentRadioName').style.cursor = "hand";
+            if(keyList.length > 0){
+                let stationName = keyList[0];
+                let stationId = stationDict[stationName]
+                currentRadioName.innerText = stationName; /*stationName.substring(0, 20)*/
+                currentRadioName.setAttribute("id", "currentRadioName");
+                currentRadioName.style.cursor = "pointer";
+                currentRadioName.style.cursor = "hand";
                 $("#currentRadioName").on('click', function () {
-                    document.getElementById('dot_' + station_id).scrollIntoView({ behavior: "smooth" });
+                    document.getElementById('dot_' + stationId).scrollIntoView({ behavior: "smooth" });
                 });
-                currentRadio = station;
-            }/* if */
+                currentRadio = stationName;
+            }
         }
-
-    });
-
-}
-;
-
-function cookie_del_station() {
-    let req;
-
-    req = $.ajax({
-        type: 'POST',
-        url: "/cookie_del_station",
-        cache: false
-    });
-
-}
-;
-
-function cookie_set_streamer() {
-    let req;
-
-    req = $.ajax({
-        type: 'POST',
-        url: "/cookie_set_streamer",
-        cache: false
     });
 }
 ;
 
-function cookie_del_streamer() {
+function streamerGet() {
+        /*
+    redraw dropdown dialog for streamer in console after page refresh
+    "keeps track of your records"
+    */
     let req;
-    req = $.ajax({
-        type: 'POST',
-        url: "/cookie_del_streamer",
-        cache: false
-    });
-}
-;
-
-function cookie_get_streamer() {
-    let req;
-
     req = $.ajax({
         type: 'GET',
-        url: "/cookie_get_streamer",
+        url: "/streamer_get",
         cache: false,
     });
-
     req.done(function (data) {
-
-        if (data.str_streamer) {
+        if (data.streamerGet) {
             $('#cacheList').find('option:not(:first)').remove();
-
-            let streamer = data.str_streamer.split(",");
-
-            $.each(streamer, function (idx, val) {
-                let stream = val;
-
-                if (stream.length !== 0) {
-                    if (data.str_streamer === 'empty_json') {
-
-                        $('#cacheList').find('option:not(:first)').remove();
-                        cookie_del_streamer();
-                        return;
-                    }
-                    stream = val.split("=");
-                    let table_id = stream[1];
-                    let title = stream[0];
-                    cacheListFeed(table_id, title);
-                }
-
-            });
-
+            let streamerDict = data.streamerGet
+            for(name in streamerDict){
+                let table_id = streamerDict[name];
+                cacheListFeed(table_id, name);
+            }
         }
-        ; /*if (data.streamer)*/
-
-    });  /*req.done*/
-
+    });
 }
-;  /*function cookie_get_streamer*/
+;
 
 function cookie_set_show_visuals() {
     let req;
@@ -352,11 +329,8 @@ function cookie_toggle_show_visuals() {
             canvasMaster.style.display = "inline-block";
             DivCanvasMaster.style.display = "inline-block";
             cookie_set_show_visuals();
-
-            var ctx = canvasMaster.getContext("2d");
-            ctx.font = "16px Arial";
-            ctx.fillStyle = "rgb(219, 111, 52)";
-            ctx.fillText("reload page to activate analyser", 10, 50);
+            spectrumAnalyserShow = true;
+            overrideSpectrumAnalyser()
         }
         if (show_visuals === 'show_visuals') {
             analyserBadge.textContent = "show";
@@ -390,13 +364,7 @@ function cookie_start_set_text_show_visuals() {
             canvasMaster.style.display = "inline-block";
             DivCanvasMaster.style.display = "inline-block";
             spectrumAnalyserShow = true;
-
-            var ctx = canvasMaster.getContext("2d");
-            ctx.font = "14px Arial";
-            ctx.fillStyle = "rgb(219, 111, 52)";
-            ctx.fillText("select a radio to activate analyser", 10, 50);
-
-
+            overrideSpectrumAnalyser()
         }
         if (show_visuals !== 'show_visuals') {
             analyserBadge.textContent = "show";
@@ -404,10 +372,7 @@ function cookie_start_set_text_show_visuals() {
             DivCanvasMaster.style.display = "none";
             spectrumAnalyserShow = false;
         }
-
-
     });
-
 }
 ;
 
@@ -435,7 +400,7 @@ function setColor(val) {
 
     req = $.ajax({
         type: 'GET',
-        url: "/getcookiedark",
+        url: "/cookie_get_dark",
         cache: false
     });
     req.done(function (data) {
@@ -466,7 +431,7 @@ function setColor(val) {
             bodyStyles.setProperty('--controls-background', 'rgba(26,26,26,1)');
             bodyStyles.setProperty('--canvasMaster', 'rgba(26,26,26,0.85)');
 
-            setDarkmode();
+            setDarkMode();
         }
         if (color === 'white') {
             bodyStyles.setProperty('--background-color', '#ccc');
@@ -487,35 +452,23 @@ function setColor(val) {
             bodyStyles.setProperty('--controls-background', '#565454');
             bodyStyles.setProperty('--canvasMaster', '#ccc');    // rgba(240, 240, 240, 0.85)
 
-            delDarkmode();
+            delDarkMode();
         }
     });
 }
 ;
 
-
-function cookieStuff() {
-    getDarkmode();
-
-    cookie_set_streamer();
-    cookie_get_streamer();
-    cookie_set_station();
-    cookie_get_station();
-}
-;
-
-function meta_info() {
+function headerInfo() {
 
     let req = $.ajax({
         type: 'GET',
-        url: "/cache_info",
+        url: "/header_info",
         cache: false
     });
 
     req.done(function (data) {
-        if (data.cache_result !== "-empty-") {
-            let dict_io_lists = data.cache_result
-            $.each(dict_io_lists, function (idx, val) {
+        if (data.header_result !== "-empty-") {
+            $.each(data.header_result, function (idx, val) {
 
                 let response_time = val[0];
                 let suffix = val[1];
@@ -539,7 +492,7 @@ function meta_info() {
 }
 ;
 
-function delete_info() {
+function deleteInfo() {
 
     let req = $.ajax({
         type: 'GET',
@@ -586,7 +539,7 @@ function cacheListFeed(table_id, title) {
 }
 ;
 
-function toggle_show_select_box() {
+function toggleShowSelectBox() {
     if (document.getElementById('cacheList').style.color !== "rgb(219, 111, 52)") {
         document.getElementById("cacheList").style.display = "none";
     }
@@ -618,7 +571,7 @@ update_file_list = function () {
     }
     output.innerHTML = '<ul>' + children + '</ul>';
 }
-    ;
+;
 
 /**
  * Shuffles array in place. ES6 version
@@ -634,30 +587,6 @@ function shuffle_array(array) {
 }
 ;
 
-/**
- *  calculateMediaDuration()
- *  Force media element duration calculation.
- *  Returns a promise, that resolves when duration is calculated; needed for aacp broken time lines, not working so far
- **/
-function calculateMediaDuration(media) {
-    return new Promise((resolve, reject) => {
-        media.onloadedmetadata = function () {
-            // set the mediaElement.currentTime  to a high value beyond its real duration
-            media.currentTime = Number.MAX_SAFE_INTEGER;
-            // listen to time position change
-            media.ontimeupdate = function () {
-                media.ontimeupdate = function () { };
-                // setting player currentTime back to 0 can be buggy too, set it first to .1 sec
-                media.currentTime = 0.1;
-                media.currentTime = 0;
-                // media.duration should now have its correct value, return it...
-                resolve(media.duration);
-            }
-        }
-    });
-}
-;
-
 function getBodyColor() {
     let bodyStyle = window.getComputedStyle(document.body, null);
     let backgroundColor = bodyStyle.backgroundColor;
@@ -676,46 +605,7 @@ function getRandomIntInclusive(min, max) {
 }
 ;
 
-$(document).ready(function () {
-
-    document.getElementById('pageCover').addEventListener('click', removePageCover);
-    pageCoverAnimation();
-
-    $('[data-toggle="tooltip"]').tooltip()
-    cookieStuff();
-    cookie_start_set_text_show_visuals();
-    setInterval(delete_info, 2505);
-    setInterval(meta_info, 5004);
-    setInterval(toggle_show_select_box, 5003);
-    setInterval(updateMasterprogress, 5002);
-    setInterval(updateDisplay, 5001);
-    audio.volume = 0.25;     // after page reload
-
-    audio.addEventListener("play", function () {
-        playBtn.style.display = "none";
-        pauseBtn.style.display = "block";
-        pauseBtn.style.cursor = "pointer";
-        pauseBtn.style.cursor = "hand";
-        $("#pauseBtn").on('click', function () {
-            audio.pause();
-        });
-    });
-    audio.addEventListener("pause", function () {
-        playBtn.style.display = "block";
-        pauseBtn.style.display = "none";
-        playBtn.style.cursor = "pointer";
-        playBtn.style.cursor = "hand";
-        $("#playBtn").on('click', function () {
-            audio.play();
-        });
-    });
-
-    audioVolumeController.addEventListener("input", setAudioVolume);
-    audioGainController.addEventListener("input", setAudioGain);
-
-    // local audio
-    fileUpload.addEventListener("change", function () {
-        var audio_duration;
+function playLocalAudio() {
 
         stopVisualise();
 
@@ -724,9 +614,9 @@ $(document).ready(function () {
         playlist_title.style.display = "block";
         playlist_section.style.display = "block";
 
-        document.getElementById('currentRadioName').innerText = "local playlist"; /*currentRadioName.substring(0, 20)*/
-        document.getElementById('currentRadioName').style.cursor = "pointer";
-        document.getElementById('currentRadioName').style.cursor = "hand";
+        currentRadioName.innerText = "local playlist"; /*currentRadioName.substring(0, 20)*/
+        currentRadioName.style.cursor = "pointer";
+        currentRadioName.style.cursor = "hand";
         $("#currentRadioName").on('click', function () {
             document.getElementById('file_list').scrollIntoView({ behavior: "smooth" });
         });
@@ -750,23 +640,16 @@ $(document).ready(function () {
         audio.src = URL.createObjectURL(play_list[0]);
         playlist_title.value = play_list[0].name;
 
-        /*
-    calculateMediaDuration(audio).then(() => {
-        console.log(audio.duration);
-    });
-    */
         let isPlayList = false;
         reloadAudioElement(audio.src, isPlayList);
-        // setTimeout(() => {
-        //     audio.pause();
-        //     audio.currentTime = Number.MAX_SAFE_INTEGER; // chrome bug; NaN, infinity
-        // }, audio_duration);
 
         let track = 1;
+        // recalls function if audio ends
         audio.onended = function () {
             if (track < play_list.length) {
 
                 audio.src = URL.createObjectURL(play_list[track]);
+                // show title in input type="text"
                 playlist_title.value = play_list[track].name;
                 stopVisualise();
                 let isPlayList = true;
@@ -776,138 +659,128 @@ $(document).ready(function () {
             }
         }
 
-    });  // file_up
+}
+;
+
+function recOrListenAction() {
+
+    if ($(this).attr("class") === "navbar-toggle collapsed") {
+
+        return;
+    }
+    ;
+
+    let clicked = $(this).attr("name");
+    let class_val = $(this).attr("class");
+    let id = $(this).attr("id");
+
+    if (class_val === "btn btn-primary") {
+        $('#' + id).removeClass("btn btn-primary");
+        $('#' + id).addClass("btn btn-danger");
+    }
+    ;
+    if (class_val === "btn btn-danger") {
+        $('#' + id).removeClass("btn btn-danger");
+        $('#' + id).addClass("btn btn-primary");
+    }
+    ;
+
+    let dict = {
+        'name': clicked,
+        'button_id': id
+
+    };
+    req = $.ajax({
+        type: 'POST',
+        dataType: "json",
+        url: "/",
+        data: dict
+    });
 
 
-    $("button").click(function () {
+    req.done(function (data) {
+        if (data.streamer) {
 
-        if ($(this).attr("class") === "navbar-toggle collapsed") {
+            $('#cacheList').find('option:not(:first)').remove();
+            let streamer = data.streamer.split(",");
+
+            $.each(streamer, function (idx, val) {
+
+                let stream = val;
+                if (stream.length !== 0) {
+                    stream = val.split("=");
+                    let table_id = stream[1];
+                    let title = stream[0];
+                    cacheListFeed(table_id, title);
+
+                    if (data.streamer === 'empty_json') {
+                        $('#cacheList').find('option:not(:first)').remove();
+                        document.getElementById('cacheList').style.color = "#696969";
+                        document.getElementById('cacheList').style.textColor = "#696969";
+                    }
+                    console.log('data.streamer ' + data.streamer);
+
+                }
+
+            });    /*each*/
 
-            return;
         }
         ;
 
-        let clicked = $(this).attr("name");
-        console.log("send name " + clicked);
-        let class_val = $(this).attr("class");
-        console.log("send button " + class_val);
-        let id = $(this).attr("id");
-        let dict = {
-            'name': clicked,
-            'class_val': class_val,
-            'button_id': id
+        if (data.radio_table_id) {
 
-        };
-        req = $.ajax({
-            type: 'POST',
-            dataType: "json",
-            url: "/",
-            data: dict
-        });
-        $('#' + id).fadeOut(1).fadeIn(3);
+        }
+        ;
 
-        req.done(function (data) {
+        /* current play station */
 
-            if (data.class_val === "btn btn-primary") {
-                $('#' + id).removeClass("btn btn-primary");
-                $('#' + id).addClass("btn btn-danger");
-            }
-            ;
+        if (data.table_ident) {
 
-            if (data.class_val === "btn btn-danger") {
-                $('#' + id).removeClass("btn btn-danger");
-                $('#' + id).addClass("btn btn-primary");
-            }
-            ;
+            let radioName = data.table_ident;
+            console.log('table_ident ' + radioName);
 
-            if (data.streamer) {
-                /* Del all streamer, push current in combo box */
-                cookie_set_streamer();
-                $('#cacheList').find('option:not(:first)').remove();
-                let streamer = data.streamer.split(",");
+            if (radioName !== 'Null') {
 
-                $.each(streamer, function (idx, val) {
-
-                    let stream = val;
-                    if (stream.length !== 0) {
-                        stream = val.split("=");
-                        let table_id = stream[1];
-                        let title = stream[0];
-                        cacheListFeed(table_id, title);
-
-                        if (data.streamer === 'empty_json') {
-                            $('#cacheList').find('option:not(:first)').remove();
-                            document.getElementById('cacheList').style.color = "#696969";
-                            document.getElementById('cacheList').style.textColor = "#696969";
-                            cookie_del_streamer();
-                        }
-                        console.log('data.streamer ' + data.streamer);
-
-                    }
-
-                });    /*each*/
+                currentRadioName.innerText = radioName; /*currentRadioName.substring(0, 20)*/
+                currentRadioName.style.cursor = "pointer";
+                currentRadioName.style.cursor = "hand";
+                $("#currentRadioName").on('click', function () {
+                    document.getElementById('dot_' + id).scrollIntoView({ behavior: "smooth" });
+                });
 
             }
-            ;
-
-            if (data.radio_table_id) {
-
+            if (data.former_button_to_switch) {
+                let num = data.former_button_to_switch;
+                console.log('auto_click former_button_to_switch: ' + num);
+                $("#" + num).click();
+            } else {
+                console.log('... No button to switch');
             }
+
             ;
+        }
+        ;
 
-            /* current play station */
-
-            if (data.table_ident) {
-
-                var currentRadioName = data.table_ident;
-                console.log('table_ident ' + currentRadioName);
-
-                if (currentRadioName !== 'Null') {
-
-                    cookie_set_station(currentRadioName, id);
-
-                    document.getElementById('currentRadioName').innerText = currentRadioName; /*currentRadioName.substring(0, 20)*/
-                    document.getElementById('currentRadioName').style.cursor = "pointer";
-                    document.getElementById('currentRadioName').style.cursor = "hand";
-                    $("#currentRadioName").on('click', function () {
-                        document.getElementById('dot_' + id).scrollIntoView({ behavior: "smooth" });
-                    });
-
-                }
-                if (data.former_button_to_switch) {
-                    let num = data.former_button_to_switch;
-                    console.log('auto_click former_button_to_switch: ' + num);
-                    $("#" + num).click();
-                }
-                ;
-            }
-            ;
-
-            if (data.result === 'deactivate_audio') {
-                console.log('deactivate_audio');
-                audio.src = "";
-                audio.currentTime = 0;
-                audio.srcObject = null;
-                document.getElementById('currentRadioName').innerText = '';
-                cookie_del_station();
-            }
-            ;
-
-            if (data.result === 'activate_audio') {
-                console.log('activate_audio');
-                stopVisualise();
-
-                let newSource = localHostSoundRoute + currentRadioName;
-                let isPlayList = false;
-                reloadAudioElement(newSource, isPlayList);
-            }
-            ;
-
-        });
+        if (data.result === 'deactivate_audio') {
+            console.log('deactivate_audio');
+            audio.src = "";
+            audio.currentTime = 0;
+            audio.srcObject = null;
+            currentRadioName.innerText = '';
+        }
+        ;
 
+        if (data.result === 'activate_audio') {
+            stopVisualise();
+            let localHostSoundRoute  = data.sound_endpoint
+            let radioName = data.table_ident
+            let newSource = localHostSoundRoute + radioName;
+            let isPlayList = false;
+            reloadAudioElement(newSource, isPlayList);
+        }
+        ;
 
     });
 
-}); /* doc.window */
-
-
+}
+;
