@@ -8,9 +8,10 @@ def stream_audio_feed(name):
     while True:
 
         try:
+            # drain the audio element as fast as possible for switching stations
             if not ghettoApi.listen_active_dict[name]:
                 return
-            """grab from queue"""
+            # grab from queue
             if not ghettoApi.ghetto_audio_stream_dict[name + ',audio'].empty():
                 chunk = ghettoApi.ghetto_audio_stream_dict[name + ',audio'].get()
                 yield chunk
