@@ -61,3 +61,13 @@ def remove_special_chars(str_name):
     # my_str = "hey th~!ere. /\ coolleagues?! Straße"
     rv = str_name.translate({ord(string): "" for string in '"!@#$%^*()[]{};:,./<>?\|`~=+"""'})
     return rv
+
+
+def radio_start_page_url_get(radio_name):
+    radio_id = ""
+    for id_num, name in ghettoApi.radios_in_view_dict.items():
+        if name == radio_name:
+            radio_id = id_num
+    port = ghettoApi.work_port
+    radio_start_page_url = 'http://localhost:' + str(port) + '/#dot_' + str(radio_id)
+    return radio_start_page_url
