@@ -28,7 +28,6 @@ import queue
 import shutil
 import threading
 import urllib.parse
-import urllib.parse
 import urllib.request
 from concurrent.futures import ThreadPoolExecutor
 from time import sleep, strftime, time
@@ -40,8 +39,9 @@ from eisenradio.api import ghettoApi
 # logging.basicConfig(level=logging.DEBUG, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 # logging.basicConfig(level=logging.INFO, format='[%(levelname)s] (%(threadName)-10s) %(message)s',)
 
-version = '1.5'
-print(f'ghettorecorder {version} (eisen_radio module)')  # ########## version #############
+version = '2.1'
+print(f'ghettorecorder {version} (Eisenradio     module)')
+# ########## version #############
 
 
 class GBase:
@@ -79,7 +79,7 @@ class GBase:
 
     @staticmethod
     def this_time():
-        time_val = strftime("%Y-%m-%d %H:%M:%S")
+        time_val = strftime("_%Y_%m_%d_%H.%M.%S")
         return time_val
 
     def countdown(self, instance_attr_time):
@@ -97,16 +97,6 @@ class GBase:
 
 class GIni(GBase):  # remnant of command line version
 
-    ini_keys = {}  # cls attribute to store selections from ini file, works because of key[key] = value, else not
-    srv_param_dict = {}  # all ini keys plus short url, suffix, server type stuff
-    start_stop_recording = {}  # ini key: 'start' , 'stop'; while loop check start, working check stop go upper while
-    # ini_key + '_single_title', ini_key + '_rec_from_here'
-    cost_current_ini = ''  # ini key for cost_dict calc / should be a dict
-    cost_dict = {}  # stores len of received headers to calc amount of data searching strings per day
-    # list of search strings delimiter blank, first key is named 'STRINGS': Britney Phantom ไม่เคยจะจำ Elton Jim techno
-    search_dict = {'STRINGS': 'Britney Spears ไม่เคยจะจำ Elton AC/DC techno Band feat. mix'}  # only show it is working
-    list_items = []  # radio key names for display in terminal
-    search_title_keys_list = []  # radio short keys, not start recording all streams, only searched titles
     content_type = {}  # header info audio/mpeg
 
     @staticmethod
@@ -146,8 +136,6 @@ class GNet(GBase):
             GBase.dict_error[str_radio] = f'{str_radio} radio: {error} {url}'
             return False
         except Exception as error:
-            """catch timeout here, real life - stackoverflow is not correct to say part of URLError, 
-            had to update this. Since this is not a thread used def the whole app goes down the drain"""
             print(f' ---> {str_radio} server exception: {error} , {url}')
             GBase.dict_error[str_radio] = f'{str_radio} radio: {error} {url}'
             return False
@@ -188,13 +176,10 @@ class GNet(GBase):
 
 
 class GRecorder:
-    unknown_title_name = 'unknown_title'
     path_record_dict = {}  # {station : file path}
     current_song_dict = {}  # each thread writes the new title to the station key name {station : title}
     ghettoApi.init_ghetto_radios_metadata_text(current_song_dict)
     start_write_command = {}  # recorder head thread set command to copy first file
-    search_pattern_found = {}
-
     record_active_dict = {}
     listen_active_dict = {}
     ghettoApi.init_ghetto_listen_active_dict(listen_active_dict)
@@ -202,100 +187,22 @@ class GRecorder:
     ghettoApi.init_ghetto_measurements(ghetto_measure)
     audio_stream_queue_dict = {}
     ghettoApi.init_ghetto_audio_stream(audio_stream_queue_dict)
-
-    @staticmethod
-    def ghetto_recorder_display_title(str_radio, str_action):
-        """display on terminal"""
-        # print(f' ghetto_recorder_display_title: {str_radio}')
-        update_terminal = ''
-        stream_song_name = ''
-        stop_while = False
-        try:
-            stream_song_name = GRecorder.current_song_dict[str_radio]
-        except KeyError:
-            pass
-        GRecorder.search_pattern_found[str_radio] = False
-
-        while 1:
-
-            if not len(stream_song_name) <= 2:
-                #  GRecorder.current_song_dict[str_radio] = stream_song_name  # WRITE SONG NAME   # :DEACTIVATED:
-                stream_song_name = GRecorder.current_song_dict[str_radio]  # :REVERSE:
-
-                if not update_terminal == stream_song_name:
-                    update_terminal = stream_song_name
-                    try:
-                        print(f'\t\t {GBase.this_time().split()[1]} title on {str_radio}: \t {update_terminal}')
-                    except UnicodeEncodeError:
-                        print('\t\t title on ' + str_radio + ':\t' + 'unicode error (check "$ localectl status")')
-                        print('\t\t title on ' + str_radio + ':\t' + 'consider to add additional language support.')
-
-                    except Exception as ex:
-                        print('\t\t title on ' + str_radio + ':\t' + 'unknown error (print to your terminal)')
-                        print(ex)
-                    else:
-                        pass
-            # give recorder command to record, if we got a match from search gui
-            #
-
-            try:
-                for _ in GIni.search_title_keys_list:
-                    if _ == str_radio:
-                        # search option was checked,
-                        # call - def search_pattern_start_record, search string match?
-                        got_it = GRecorder.search_pattern_start_record(stream_song_name, str_radio)
-                        if got_it:
-                            GIni.start_stop_recording[str_radio] = 'start'
-                        else:
-                            GIni.start_stop_recording[str_radio] = 'stop'
-                            GRecorder.search_pattern_found[str_radio] = False
-
-            except Exception as ex:
-                print(ex)
-
-            for sec in range(GBase.sleeper):
-                if str_action == "listen":
-                    if GBase.dict_exit[str_radio] or not GRecorder.listen_active_dict[str_radio]:
-                        stop_while = True
-                        break
-                if str_action == "record":
-                    if GBase.dict_exit[str_radio] or not GRecorder.record_active_dict[str_radio]:
-                        stop_while = True
-                        break
-                sleep(1)
-            if stop_while:
-                break
-
-    @staticmethod
-    def search_pattern_start_record(title, str_radio):
-        # search strings in title to see if we should start recording, test it in tk/tcl in ghettorecorder.win package
-        search_list = []  # chop the string
-
-        try:
-            strings = GIni.search_dict[str_radio]  # dict with user search strings
-            search_list = strings.encode('utf-8').lower().split(b' ')
-        except KeyError:
-            pass
-
-        for search_str in search_list:
-
-            if not len(search_str) <= 1:  # b'' match problem
-
-                if not title.encode('utf-8').lower().find(search_str) == -1:  # find() returns -1, if not found
-                    if not GRecorder.search_pattern_found[str_radio]:
-                        print(f'<<<< match station: {str_radio} phrase: {search_str}')
-                        GRecorder.search_pattern_found[str_radio] = True
-                    return True
-        return False
+    recorder_new_title_dict = {}
+    ghettoApi.init_ghetto_recorder_new_title(recorder_new_title_dict)
+    skipped_in_session_dict = {}
+    ghettoApi.init_ghetto_skipped_in_session_dict(skipped_in_session_dict)
 
     @staticmethod
     def ghetto_recorder_head(directory_save, stream_suffix, str_radio, str_action):
-        """create file name from current meta for recorder"""
+        """
+        clean metadata from problematic characters for writing to file system, hopefully caught all
+        create file name and path from current metadata for recorder (tail)
+        create _incomplete string to mark first and last incomplete file
+        """
         if str_action == "listen":
             return
 
-        GRecorder.start_write_command[str_radio] = False
-        sleep(3)  # chance to get stream meta info
+        sleep(3)  # chance to get stream meta info, some radios do not send metadata or send filtered out garbage
         first_record = True
 
         display_info = ""
@@ -369,25 +276,61 @@ class GRecorder:
             return False
 
     @staticmethod
-    def g_recorder_next_file(str_radio, full_file_path, record_file, ghetto_recorder, stream_request_size):
-        # COMPLETE file path has changed, new file to write; got new metadata
-        if not full_file_path == GRecorder.path_record_dict[str_radio]:
+    def g_recorder_cache_the_file(str_radio, full_file_path, record_file, ghetto_recorder, stream_request_size):
+        # extract title from path and write to "recorder_new_title_dict"
+        title = GRecorder.g_recorder_record_trace(str_radio, full_file_path)
+        if ghettoApi.blacklist_enabled_global:
+            if title not in ghettoApi.all_blacklists_dict[str_radio]:
+                GRecorder.g_recorder_remove_file(full_file_path, record_file)
+                GRecorder.g_recorder_copy_file(full_file_path, ghetto_recorder, stream_request_size)
+                print(f'\n-WRITE->>> {str_radio}: {title}\n')
+            else:
+                print(f'\n-SKIP->>> {str_radio}: {title}\n')
+                GRecorder.skipped_in_session_dict[str_radio].append(title)
+        else:
+            GRecorder.g_recorder_remove_file(full_file_path, record_file)
+            GRecorder.g_recorder_copy_file(full_file_path, ghetto_recorder, stream_request_size)
+            print(f'\n-write--> {str_radio}: {title}\n')
+
+    @staticmethod
+    def g_recorder_reset_file_offset(record_file):
+        record_file.seek(0)
+        record_file.truncate()
+
+    @staticmethod
+    def g_recorder_copy_file(full_file_path, ghetto_recorder, stream_request_size):
+        ghetto_size = os.path.getsize(ghetto_recorder)
+        if int(ghetto_size) >= int(stream_request_size):
             try:
-                if os.path.exists(full_file_path):
-                    os.remove(full_file_path)
-                record_file.flush()
+                shutil.copyfile(ghetto_recorder, full_file_path)
+            except Exception as error:
+                message = f' Exception in g_recorder_copy_file; error: {error}'
+                print(message)
+        else:
+            print('Skip file - size is too small.')
 
-                ghetto_size = os.path.getsize(ghetto_recorder)
-                if int(ghetto_size) >= int(stream_request_size):
-                    shutil.copyfile(ghetto_recorder, full_file_path)
-            except Exception as ex:
-                print(ex)
+    @staticmethod
+    def g_recorder_remove_file(full_file_path, record_file):
+        if os.path.exists(full_file_path):
+            os.remove(full_file_path)
+        record_file.flush()
 
-            record_file.seek(0)
-            record_file.truncate()
+    @staticmethod
+    def g_recorder_record_trace(str_radio, full_file_path):
+        """
+        extract the cleaned file name (in head) from path string, add to recorder_new_title_dict
+        """
+        head, tail = os.path.split(full_file_path)
+        title = ""
+        try:
+            tail_list = tail.split('.')
+            title = tail_list[0]
+        except Exception as error:
+            message = f' Exception in g_recorder_record_trace; error: {error}'
+            print(message)
 
-        full_file_path = GRecorder.path_record_dict[str_radio]  # SET NEW PATH (title) after copy
-        return full_file_path
+        GRecorder.recorder_new_title_dict[str_radio] = title
+        return title
 
     @staticmethod
     def g_recorder_teardown(str_radio, record_file, ghetto_recorder, stream_request_size):
@@ -410,6 +353,7 @@ class GRecorder:
 
     @staticmethod
     def g_recorder_empty_queue(str_radio):
+        """try to not feed Html audio element, it will switch faster"""
         while not GRecorder.audio_stream_queue_dict[str_radio + ',audio'].empty():
             GRecorder.audio_stream_queue_dict[str_radio + ',audio'].get()
 
@@ -427,9 +371,18 @@ class GRecorder:
                     if int(bit_rate) % 1 == 0:
                         return bit_rate
                 except ValueError:
-                    # got server with '128,128'
+                    # got server with '128, 128' and 64, 64 http://live02.rfi.fr/rfienvietnamien-64.mp3
                     print(f'g_recorder_ask_bit_rate ValueError: {bit_rate} {url}')
-                    return 320
+                    try:
+                        bit_rate_list = bit_rate.split(',')
+                        this_rate = bit_rate_list[0].strip()
+                        if int(this_rate) % 1 == 0:
+                            print(f'g_recorder_ask_bit_rate use: {this_rate} for {url}')
+                            return this_rate
+                    except Exception as error:
+                        message = f'use fallback rate 320, error {error}'
+                        print(message)
+                        return 320
         except Exception as ex:
             print(ex)
             return 320
@@ -449,23 +402,111 @@ class GRecorder:
         return stream_chunk_size
 
     @staticmethod
-    def g_recorder_rec(request, str_radio, ghetto_recorder, stream_chunk_size, full_file_path):
-
+    def g_recorder_rec(request, str_radio, ghetto_recorder, stream_chunk_size, full_file_path, suffix):
+        """
+        rec loop
+        start with correct path
+        must recognize change in metadata to work on header and tail of datastructure is cut out of the stream
+        """
         with open(ghetto_recorder, 'wb') as record_file:
             for chunk in request.stream(stream_chunk_size):
-                record_file.write(chunk)
-                new_file_path = GRecorder.g_recorder_next_file(str_radio,
-                                                               full_file_path,
-                                                               record_file,
-                                                               ghetto_recorder,
-                                                               stream_chunk_size)
-                full_file_path = new_file_path
+
+                if not full_file_path == GRecorder.path_record_dict[str_radio]:
+                    # new file path found
+                    GRecorder.record_write_last(chunk, record_file, suffix)
+                    GRecorder.g_recorder_cache_the_file(str_radio,
+                                                        full_file_path,
+                                                        record_file,
+                                                        ghetto_recorder,
+                                                        stream_chunk_size)
+                    GRecorder.g_recorder_reset_file_offset(record_file)
+                    GRecorder.record_write_first(chunk, record_file, suffix)
+                    full_file_path = GRecorder.path_record_dict[str_radio]
+                else:
+                    # fill a current file, write chunk
+                    record_file.write(chunk)
 
                 if not GRecorder.record_active_dict[str_radio] or GBase.dict_exit[str_radio]:  # timer dict_exit
                     GRecorder.g_recorder_teardown(str_radio, record_file, ghetto_recorder, stream_chunk_size)
                     request.release_conn()
                     break
 
+    @staticmethod
+    def record_write_first(chunk, record_file, suffix):
+        if suffix == ".aacp" or suffix == ".aac":
+            acp_header = GRecorder.record_acp_fff1_sync_word_header(chunk)
+            if acp_header is not None:
+                record_file.write(acp_header)
+        else:
+            # ('write first chunk of new file')
+            record_file.write(chunk)
+
+    @staticmethod
+    def record_write_last(chunk, record_file, suffix):
+        if suffix == ".aacp" or suffix == ".aac":
+            # ('write cleaned file tail')
+            acp_tail = GRecorder.record_acp_fff1_sync_word_tail(chunk)
+            if acp_tail is not None:
+                record_file.write(acp_tail)
+        else:
+            # ('last normal chunk of current file')
+            record_file.write(chunk)
+
+    @staticmethod
+    def record_acp_fff1_sync_word_tail(chunk):
+        """
+        clean cut at the end, cut out the last bytes starting with ff f1 (if not, result is a defective payload),
+        so browser do not stop with silent error and will play next file
+        """
+        hex_chunk = chunk.hex()
+        start, end = -1, -5
+        search_string = "fff1"
+        while 1:
+            if end < -(len(hex_chunk)):
+                break
+            if hex_chunk[end:start] == search_string:
+                # return bytes before end variable
+                try:
+                    return bytes.fromhex(hex_chunk[:end])
+                # ValueError: non-hexadecimal number found in fromhex() arg at position 64805
+                except ValueError:
+                    return
+                except Exception as error:
+                    message = f'unknown error in record_acp_fff1_sync_word_tail(), {error} ignore it.'
+                    print(message)
+                    return
+            start -= 1
+            end -= 1
+        return
+
+    @staticmethod
+    def record_acp_fff1_sync_word_header(chunk):
+        """
+        cut files out of the stream on metadata change, so the end of a file is not likely the correct start for new
+        search aacp (acp plus) frame start sequence to clean the file so browser do not stop with silent error
+        convert byte stream to hex, search ff f1 index_of_chunk[0] to index_of_chunk[4]
+        shift the search frame in hex to right, cut out from start and return as bytes
+        """
+        hex_chunk = chunk.hex()
+        start, end = 0, 4
+        search_string = "fff1"
+        while 1:
+            if end > len(hex_chunk):
+                break
+            if hex_chunk[start:end] == search_string:
+                # return bytes slice from shifted start to the end of chunk
+                try:
+                    return bytes.fromhex(hex_chunk[start:])
+                except ValueError:
+                    return
+                except Exception as error:
+                    message = f'unknown error in record_acp_fff1_sync_word_header(), {error} ignore it.'
+                    print(message)
+                    return
+            start += 1
+            end += 1
+        return
+
     @staticmethod
     def ghetto_recorder_tail(url, str_radio, path_to_save, suffix, str_action):
 
@@ -480,18 +521,15 @@ class GRecorder:
             GRecorder.g_recorder_await_head(str_radio)
             full_file_path = GRecorder.g_recorder_path_transfer_test(str_radio)
             if not full_file_path:
+                print(f'{str_radio} Recorder can not get filepath')
                 return
             if not GRecorder.g_recorder_make_dir(path_to_save, str_radio):
+                print(f'{str_radio} Recorder can not create directory')
                 return
-            GRecorder.g_recorder_rec(request, str_radio, ghetto_recorder, stream_chunk_size, full_file_path)
+            GRecorder.g_recorder_rec(request, str_radio, ghetto_recorder, stream_chunk_size, full_file_path, suffix)
 
-        # k = 0
         if str_action == "listen":
             for chunk in request.stream(stream_chunk_size):
-                # if k % 10 == 0:
-                #     for thread in threading.enumerate():
-                #         print(f' {thread.name}   {k}')
-                # k += 1
 
                 GRecorder.g_recorder_write_queue(str_radio, chunk)
                 if not GRecorder.listen_active_dict[str_radio] or GBase.dict_exit[str_radio]:
@@ -527,7 +565,7 @@ class GRecorder:
             pass
 
     @staticmethod
-    def metadata_icy_info(request):
+    def metadata_icy_info(request, str_radio):
         try:
             icy_meta_int = int(request.headers['icy-metaint'])
             request.read(icy_meta_int)
@@ -536,8 +574,9 @@ class GRecorder:
             num_of_bytes = start_int * 16
             metadata_content = request.read(num_of_bytes)
             return metadata_content
-        except Exception as e:
-            print(e)
+        except Exception as error:
+            message = f'metadata_icy_info(), {str_radio}: no or false metadata; {error}'
+            print(message)
             return False
 
     @staticmethod
@@ -592,7 +631,7 @@ class GRecorder:
                 response = GRecorder.metadata_request(url)
                 request_time = round((time() - start_time) * 1000)
                 GRecorder.metadata_header_info(response, str_radio, request_time)
-                icy_info = GRecorder.metadata_icy_info(response)
+                icy_info = GRecorder.metadata_icy_info(response, str_radio)
                 response.release_conn()  # preload_content=False
             except HTTPError:
                 pass
@@ -664,6 +703,7 @@ class GRecorder:
 
 def check_alive_playlist_container(str_radio, str_url):
     # playlist url?
+    # https://streams.br.de/bayern1obb_2.m3u
     if str_url[-4:] == '.m3u' or str_url[-4:] == '.pls':  # or url[-5:] == '.m3u8' or url[-5:] == '.xspf':
         # take first from the list
         is_playlist_server = GRecorder.playlist_m3u(str_url, str_radio)
@@ -680,9 +720,6 @@ def check_alive_playlist_container(str_radio, str_url):
 
 
 def record_start_radio(str_radio, url, stream_suffix, dir_save, str_action):
-    # threading.Thread(name=str_radio + '_' + str_action + "_show", target=GRecorder.ghetto_recorder_display_title,
-    #                  args=(str_radio, str_action),
-    #                  daemon=True).start()
     threading.Thread(name=str_radio + '_' + str_action + "_head", target=GRecorder.ghetto_recorder_head,
                      args=(dir_save, stream_suffix, str_radio, str_action),
                      daemon=True).start()
@@ -697,14 +734,14 @@ def record_start_radio(str_radio, url, stream_suffix, dir_save, str_action):
 def record(str_radio, url, str_action):
     stream_suffix = GNet.stream_filetype_url(url, str_radio)
     if str_action == "record":
-        GRecorder.current_song_dict[str_radio] = GRecorder.unknown_title_name
+        GRecorder.current_song_dict[str_radio] = 'unknown_title' + GBase.this_time()
+        GRecorder.start_write_command[str_radio] = False
+        GRecorder.skipped_in_session_dict[str_radio] = []
     if str_action == "listen":
         GRecorder.current_song_dict[str_radio] = ""
-    GIni.start_stop_recording[str_radio] = 'start'  # remnant of hit keyword, start record in tk/tcl g.recorder
-    # GIni.start_stop_recording[str_radio] = 'stop'   # init it here, checkbox user interface
-    GIni.start_stop_recording[str_radio + '_adv'] = 'start_from_here'
 
-    dir_save = GBase.radio_base_dir + '//' + str_radio    # [Baustelle]
+    GBase.dict_exit[str_radio] = False
+    dir_save = os.path.join(GBase.radio_base_dir, str_radio)  # overwritten in eishome.set_radio_path()
     record_start_radio(str_radio, url, stream_suffix, dir_save, str_action)
 
     # ################################## end ########################################
