@@ -22,7 +22,7 @@ class TestRouteHome(unittest.TestCase):
         from eisenradio.lib.eisdb import status_read_status_set
         from eisenradio.eisenhome import routes as home_routes
 
-        app = create_app(True)  # True is test
+        app = create_app(5050, True)  # port info for sound route, True is test (but app is only part. init)
 
         print('\n ... Begin: def test_route_home()')
 
@@ -42,20 +42,20 @@ class TestRouteHome(unittest.TestCase):
         assert home_routes.eisenhome_bp.template_folder == 'bp_home_templates'
         assert home_routes.eisenhome_bp.static_url_path == '/bp_home_static'
 
-        print(""" /setcookiedark """)
+        print(""" /cookie_set_dark """)
 
-        rv = web.get('/setcookiedark')
+        rv = web.get('/cookie_set_dark')
         assert rv.status_code == 200
         assert 'Eisenkekse sind die besten' in rv.data.decode('utf-8')
 
-        print(""" /getcookiedark (json style) """)
+        print(""" /cookie_get_dark (json style) """)
 
-        rv = web.get('/getcookiedark')
+        rv = web.get('/cookie_get_dark')
         data = json.loads(rv.get_data(as_text=True))
         assert rv.status_code == 200
         assert data['darkmode'] == 'darkmode'
 
-        print(""" /getcookiedark (flask client.cookie_jar style) """)
+        print(""" /cookie_get_dark (flask client.cookie_jar style) """)
 
         cookie = next(
             (cookie for cookie in web.cookie_jar if cookie.name == "eisen-cookie"),
@@ -64,9 +64,9 @@ class TestRouteHome(unittest.TestCase):
         assert cookie is not None
         assert cookie.value == "darkmode"
 
-        print(""" /delcookiedark """)
+        print(""" /cookie_del_dark """)
 
-        rv = web.post('/delcookiedark',
+        rv = web.post('/cookie_del_dark',
                       headers={"X-Requested-With": "XMLHttpRequest"},
                       follow_redirects=True, )
         cookie = rv.headers.getlist('Set-Cookie')
@@ -86,7 +86,7 @@ class TestRouteHome(unittest.TestCase):
         assert data == timer
         assert rv.status_code == 200
 
-        print(""" /getcookiedark """)
+        print(""" /cookie_get_dark """)
 
         rv = web.post('/index_posts_percent',
                       follow_redirects=True,
@@ -112,7 +112,7 @@ class TestRouteHome(unittest.TestCase):
                      )
         data = json.loads(rv.get_data(as_text=True))
         assert rv.status_code == 200
-        assert data['result'] == {'2': 'OVAN 오반 - I Need You 어떻게 지내',
+        assert data['updateDisplay'] == {'2': 'OVAN 오반 - I Need You 어떻게 지내',
                                   '3': 'Henrik Freischlader Band - Take The Blame',
                                   '6': 'Yoko Kanno and The Seatbelts - Waltz for Zizi'}
 
